@@ -1,6 +1,6 @@
 from typing import List, Dict
 
-from cloudrail.knowledge.context.environment_context import EnvironmentContext
+from cloudrail.knowledge.context.aws.aws_environment_context import AwsEnvironmentContext
 from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
 from cloudrail.knowledge.rules.base_rule import Issue
 from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType
@@ -11,7 +11,7 @@ class EnsureApiGwCachingEncryptedRule(AwsBaseRule):
     def get_id(self) -> str:
         return 'non_car_api_gateway_caching_encrypted'
 
-    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
+    def execute(self, env_context: AwsEnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
         issues: List[Issue] = []
         for api_gw in env_context.rest_api_gw:
             if api_gw.method_settings and api_gw.method_settings.caching_enabled and not api_gw.method_settings.caching_encrypted:
@@ -20,5 +20,5 @@ class EnsureApiGwCachingEncryptedRule(AwsBaseRule):
                           f"method `{api_gw.method_settings.http_method.value}` in the stage `{api_gw.method_settings.stage_name}`", api_gw, api_gw))
         return issues
 
-    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
+    def should_run_rule(self, environment_context: AwsEnvironmentContext) -> bool:
         return bool(environment_context.rest_api_gw)
